<?php

if (!defined('ABSPATH')) {
    exit();
}



class PPT_Video_Galley_Elementor_Widget extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'ppt_video_gallery';
    }

    public function get_title()
    {
        return esc_html__('PPT Video Gallery ', 'ppt');
    }

    public function get_icon()
    {
        return 'eicon-video-playlist';
    }

    public function get_categories()
    {
        return ['ppt-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section('content_section', [
            'label' => esc_html__('Content', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title', [
            'label' => esc_html__('Title', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('duration', [
            'label' => esc_html__('Duration', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);
        
        $repeater->add_control('embed', [
            'label' => esc_html__('Embed Code', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('image', [
            'label' => esc_html__('Image', 'ppt'),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
        ]);


        $this->add_control('video', [
            'label' => esc_html__('Videos', 'ppt'),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section();

        $this->start_controls_section('style_section', [
            'label' => esc_html__('Style', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);


        $this->add_control(
            'title_align',
            [
                'label' => esc_html__( 'Title Alignment', 'ppt' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'ppt' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'ppt' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'ppt' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-title' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_size',
            [
                'label' => esc_html__( 'Title Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-title' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_control(
            'duration_align',
            [
                'label' => esc_html__( 'Duration Alignment', 'ppt' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'ppt' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'ppt' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'ppt' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-duration' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => esc_html__( 'Duration Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-duration' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'text_size',
            [
                'label' => esc_html__( 'Duration Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-duration' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_control(
            'play_icon_color',
            [
                'label' => esc_html__( 'Play Icon Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} svg.ppt-icon-v1.ppt-icon-v1-sm g path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        
        $this->add_control(
            'close_icon_color',
            [
                'label' => esc_html__( 'Close Icon Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} svg.ppt-icon-v1.ppt-icon-v1-sm' => 'color: {{VALUE}}',
                ],
            ]
        );
        
        $this->add_control(
            'icon_background',
            [
                'label' => esc_html__( 'Icon Background Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-video-card-v1-play-btn:before, button.ppt-modal-close-btn-v1.ppt-modal-close-btn-v1-outer.ppt-js-modal-v1-close.js-tab-focus' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if ($settings['video']) { $counter = 1; ?>

            <div class="ppt-video-gallery-v1">
              <div class="ppt-video-gallery-v1-container">
                <ul class="ppt-video-gallery-v1-grid">
                <?php foreach ($settings['video'] as $video) { ?>
                    <li>
                        <div class="ppt-video-card-v1">
                          <a href="#0" class="ppt-video-card-v1-modal-control" aria-controls="modal-video-1" data-url="<?php echo $video['embed']; ?>" role="button">
                            <?php if ( !empty( $video['image']['url'] ) ) { ?>
                            <img class="ppt-video-card-v1-preview" src="<?php echo $video['image']['url']; ?>" alt="<?php echo $video['title']; ?>">
                            <div class="ppt-video-card-v1-play-btn" aria-hidden="true">
                              <svg class="ppt-icon-v1 ppt-icon-v1-sm" viewBox="0 0 24 24">
                                <g fill="currentColor">
                                  <path d="M20.555,11.168l-15-10c-0.307-0.204-0.702-0.224-1.026-0.05C4.203,1.292,4,1.631,4,2v20 c0,0.369,0.203,0.708,0.528,0.882C4.676,22.961,4.838,23,5,23c0.194,0,0.388-0.057,0.555-0.168l15-10C20.833,12.646,21,12.334,21,12 S20.833,11.354,20.555,11.168z"></path>
                                </g>
                              </svg>
                            </div>
                            <?php } ?>
                          </a>
                          <footer>
                            <h4 class="ppt-video-card-v1-title"><?php echo $video['title']; ?></h4>
                            <p class="ppt-video-card-v1-duration"><?php echo $video['duration']; ?></p>
                          </footer>
                        </div>
                    </li>
                <?php } ?>
                </ul>
              </div>
            </div>
        <?php } ?>
        
        <div class="modal modal-is-loading-v1 ppt-flex-v1 ppt-flex-v1-center ppt-bg-black-v1 ppt-bg-opacity-90% ppt-padding-x-md-v1 ppt-js-modal-v1" id="modal-video-1" data-modal-first-focus=".ppt-modal-close-btn-v1">
          <div class="ppt-modal-content-v1 ppt-width-100% ppt-max-width-md-v1 ppt-max-height-100% ppt-overflow-auto-v1 ppt-shadow-md-v1" role="alertdialog" aria-labelledby="modal-video-title-1" aria-describedby="">
        
            <figure class="ppt-media-wrapper-16:9">
              <iframe src="" class="ppt-js-modal-v1-video-media" width="640" height="360" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>
            </figure>
          </div>
        
          <div class="ppt-modal-loader-v1" aria-hidden="true">
            <svg class="ppt-icon-v1 ppt-icon-v1-lg ppt-color-bg ppt-icon-v1-is-spinning" viewBox="0 0 48 48">
              <path d="M24,48A24,24,0,1,1,48,24,24.027,24.027,0,0,1,24,48ZM24,4A20,20,0,1,0,44,24,20.023,20.023,0,0,0,24,4Z" opacity="0.4"></path>
              <path d="M48,24H44A20.023,20.023,0,0,0,24,4V0A24.028,24.028,0,0,1,48,24Z"></path>
            </svg>
          </div>
        
          <button class="ppt-modal-close-btn-v1 ppt-modal-close-btn-v1-outer ppt-js-modal-v1-close js-tab-focus">
            <svg class="ppt-icon-v1 ppt-icon-v1-sm" viewBox="0 0 24 24">
              <title><?php echo esc_html__('Close', 'ppt'); ?></title>
              <g fill="none" stroke="currentColor" stroke-miterlimit="10" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                <line x1="3" y1="3" x2="21" y2="21" />
                <line x1="21" y1="3" x2="3" y2="21" />
              </g>
            </svg>
          </button>
        </div>        
    <?php }
}
